@@ -51,11 +51,8 @@ struct _GtkTreeModelSortClass
 {
   GObjectClass parent_class;
 
-  /* Padding for future expansion */
-  void (*_gtk_reserved1) (void);
-  void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
+  /* < private > */
+  gpointer padding[8];
 };
 
 
